% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lineqGPlikelihoods.R
\name{constrlogLikGrad}
\alias{constrlogLikGrad}
\title{Numerical Gradient of the Log-Constrained-Likelihood of a Gaussian Process.}
\usage{
constrlogLikGrad(par = model$kernParam$par, model,
  parfixed = rep(FALSE, length(par)), mcmc.opts = list(probe = "Genz",
  nb.mcmc = 1000), estim.varnoise = FALSE)
}
\arguments{
\item{par}{the values of the covariance parameters.}

\item{model}{an object with class \code{lineqGP}.}

\item{parfixed}{indices of fixed parameters to do not be optimised.}

\item{mcmc.opts}{mcmc options. \code{mcmc.opts$probe} A character string corresponding
to the estimator for the orthant multinormal probabilities.
Options: \code{"Genz"} (Genz, 1992), \code{"ExpT"} (Botev, 2017).
If \code{probe == "ExpT"}, \code{mcmc.opts$nb.mcmc}  is the number of MCMC
samples used for the estimation.}

\item{estim.varnoise}{If \code{true}, a noise variance is estimated.}
}
\value{
The gradient of the negative log-constrained-likelihood.
}
\description{
Compute the gradient numerically of the negative log-constrained-likelihood of a Gaussian Process
conditionally to the inequality constraints (Lopez-Lopera et al., 2017).
}
\details{
Orthant multinormal probabilities are estimated via (Genz, 1992; Botev, 2017).
}
\section{Comments}{

As orthant multinormal probabilities don't have explicit expressions,
the gradient is implemented numerically based on \code{\link{nl.grad}}.
}

\references{
Lopez-Lopera, A. F., Bachoc, F., Durrande, N., and Roustant, O. (2017),
"Finite-dimensional Gaussian approximation with linear inequality constraints".
\emph{ArXiv e-prints}
\href{https://arxiv.org/abs/1710.07453}{[link]}

Bachoc, F., Lagnoux, A., and Lopez-Lopera, A. F. (2018),
"Maximum likelihood estimation for Gaussian processes under inequality constraints".
\emph{ArXiv e-prints}
\href{https://arxiv.org/abs/1804.03378}{[link]}

Genz, A. (1992),
"Numerical computation of multivariate normal probabilities".
\emph{Journal of Computational and Graphical Statistics},
1:141-150.
\href{https://www.tandfonline.com/doi/abs/10.1080/10618600.1992.10477010}{[link]}

Botev, Z. I. (2017),
"The normal law under linear restrictions: simulation and estimation via minimax tilting".
\emph{Journal of the Royal Statistical Society: Series B (Statistical Methodology)},
79(1):125-148.
\href{https://rss.onlinelibrary.wiley.com/doi/pdf/10.1111/rssb.12162}{[link]}
}
\seealso{
\code{\link{constrlogLikFun}}, \code{\link{logLikFun}},
         \code{\link{logLikGrad}}
}
\author{
A. F. Lopez-Lopera.
}
